# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/position/measure.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(fintekkers/models/position/measure.proto\x12\x1a\x66intekkers.models.position*\xaa\x01\n\x0cMeasureProto\x12\x13\n\x0fUNKNOWN_MEASURE\x10\x00\x12\x15\n\x11\x44IRECTED_QUANTITY\x10\x01\x12\x10\n\x0cMARKET_VALUE\x10\x02\x12\x19\n\x15UNADJUSTED_COST_BASIS\x10\x03\x12\x17\n\x13\x41\x44JUSTED_COST_BASIS\x10\x04\x12\x11\n\rCURRENT_YIELD\x10\x05\x12\x15\n\x11YIELD_TO_MATURITY\x10\x07\x42\x11\x42\rMeasureProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.position.measure_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\rMeasureProtosP\001'
  _MEASUREPROTO._serialized_start=73
  _MEASUREPROTO._serialized_end=243
# @@protoc_insertion_point(module_scope)
