# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/transaction/transaction_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4fintekkers/models/transaction/transaction_type.proto\x12\x1d\x66intekkers.models.transaction*z\n\x14TransactionTypeProto\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x42UY\x10\x01\x12\x08\n\x04SELL\x10\x02\x12\x0b\n\x07\x44\x45POSIT\x10\x03\x12\x0e\n\nWITHDRAWAL\x10\x04\x12\x0e\n\nMATURATION\x10\x05\x12\x15\n\x11MATURATION_OFFSET\x10\x06\x42\x19\x42\x15TransactionTypeProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.transaction.transaction_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\025TransactionTypeProtosP\001'
  _TRANSACTIONTYPEPROTO._serialized_start=87
  _TRANSACTIONTYPEPROTO._serialized_end=209
# @@protoc_insertion_point(module_scope)
