# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/security/security_quantity_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7fintekkers/models/security/security_quantity_type.proto\x12\x1a\x66intekkers.models.security*h\n\x19SecurityQuantityTypeProto\x12\x19\n\x15UNKNOWN_QUANTITY_TYPE\x10\x00\x12\x17\n\x13ORIGINAL_FACE_VALUE\x10\x01\x12\x0c\n\x08NOTIONAL\x10\x02\x12\t\n\x05UNITS\x10\x03\x42\x1e\x42\x1aSecurityQuantityTypeProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.security_quantity_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\032SecurityQuantityTypeProtosP\001'
  _SECURITYQUANTITYTYPEPROTO._serialized_start=87
  _SECURITYQUANTITYTYPEPROTO._serialized_end=191
# @@protoc_insertion_point(module_scope)
