from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

ADJUSTED_COST_BASIS: MeasureProto
CURRENT_YIELD: MeasureProto
DESCRIPTOR: _descriptor.FileDescriptor
DIRECTED_QUANTITY: MeasureProto
MARKET_VALUE: MeasureProto
UNADJUSTED_COST_BASIS: MeasureProto
UNKNOWN_MEASURE: MeasureProto
YIELD_TO_MATURITY: MeasureProto

class MeasureProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
